==> ktp-accounts-kcm-0.8.80.tar.bz2: ktp-accounts-kcm-0.8.80/plugins/haze/ktpaccountskcm_plugin_haze.desktop.cmake <==
[Desktop Entry]
Encoding=UTF-8
Comment=Custom account configuration user interface for accounts using the Haze connection manager.
Comment[bs]=Korisnički interfejs za konfiguraciju korisničkih naloga koristeći Haze menadžer konekcja.
Comment[ca]=Interfície d'usuari de configuració de compte personalitzat per comptes que utilitzen el gestor de connexions Haze.
Comment[ca@valencia]=Interfície d'usuari de configuració de compte personalitzat per comptes que utilitzen el gestor de connexions Haze.
Comment[cs]=Vlastní uživatelské rozhraní nastavení účtů pro účty používající správce spojení Haze.
Comment[da]=Brugerflade til brugertilpasset kontokonfiguration til konti der bruger forbindelseshåndteringen Haze.
Comment[de]=Eigene Benutzeroberfläche zum Einrichten von Zugängen, die die Haze-Verbindungsverwaltung verwenden.
Comment[el]=Περιβάλλον προσαρμοσμένης διαμόρφωσης λογαριασμού χρήστη για λογαριασμούς που χρησιμοποιούν το διαχειριστή συνδέσεων Haze.
Comment[en_GB]=Custom account configuration user interface for accounts using the Haze connection manager.
Comment[es]=Interfaz de configuración de cuentas personalizadas para las cuentas que usen el gestor de conexiones Haze.
Comment[et]=Haze'i ühendusehaldurit kasutavate kontode kohandatud konto seadistamise kasutajaliides
Comment[fi]=Haze-yhteyshallintaa käyttävien tilien mukautettu hallintakäyttöliittymä.
Comment[fr]=Interface utilisateur personnalisée pour la configuration de comptes en utilisant le gestionnaire de connexions « Haze ».
Comment[gl]=Interface de usuario de configuración personalizada da conta para contas que empreguen o xestor de conexións Haze.
Comment[hu]=Egyedi beállítófelület a Haze kapcsolatkezelőt használó azonosítókhoz.
Comment[ia]=Interfacie de usator pro configuration de conto personalisate pro contos usante le gerente de connexion Haze.
Comment[it]=Interfaccia utente personalizzata di configurazione account per account che usano il gestore di connessioni Haze.
Comment[kk]=Haze байланыс менеджерін қолданатын тіркелгі пайдаланушы интерфейс параметрлерін ыңғайлау.
Comment[km]=ចំណុច​ប្រទាក់​អ្នក​ប្រើ​ការ​កំណត់​រចនាសម្ព័ន្ធ​គណនី​ផ្ទាល់​ខ្លួន​សម្រាប់​គណនី​ដែល​បាន​ប្រើ​កម្មវិធី​គ្រប់គ្រង​ការ​តភ្ជាប់​ Haze ។
Comment[ko]=Haze 연결 관리자를 사용하는 계정 설정 사용자 인터페이스입니다.
Comment[lt]=Savito paskyros konfigūravimo naudotojo sąsaja paskyroms naudojant Haze ryšio tvarkyklę.
Comment[nb]=Brukerflate for å sette opp egendefinerte kontoer ved bruk av Haze tilkoblingsbehandler.
Comment[nds]=Topasst Kontoinstellen-Böversiet för Kontos, de den Verbinnenpleger „Haze“ bruukt
Comment[nl]=Gebruikersinterface voor aangepaste accountconfiguratie voor accounts die de Haze verbindingenbeheerder gebruiken.
Comment[pl]=Własny interfejsu użytkownika konfiguracji kont dla kont wykorzystujących menadżera połączeń Haze.
Comment[pt]=Interface de utilizador de configuração de contas personalizadas com o gestor de ligações Haze.
Comment[pt_BR]=Interface de configuração de contas personalizadas usando o gerenciador de conexões Haze.
Comment[ro]=Interfață personalizată de configurare a conturilor folosind gestionarul de conexiuni Haze.
Comment[ru]=Пользовательский интерфейс для настройки учётной записи с помощью менеджера соединений Haze.
Comment[sk]=Vlastné používateľské rozhranie konfigurácie účtu pre účty používajúce správcu pripojení Haze.
Comment[sl]=Uporabniški vmesnik za prilagoditev računov, ki uporabljajo upravljalnik povezav Haze.
Comment[sr]=Корисничко сучеље за подешавање посебних налога под менаџером везе Хејз.
Comment[sr@ijekavian]=Корисничко сучеље за подешавање посебних налога под менаџером везе Хејз.
Comment[sr@ijekavianlatin]=Korisničko sučelje za podešavanje posebnih naloga pod menadžerom veze Haze.
Comment[sr@latin]=Korisničko sučelje za podešavanje posebnih naloga pod menadžerom veze Haze.
Comment[sv]=Användargränssnitt för anpassad kontoinställning av konton som använder anslutningshanteraren Haze.
Comment[tr]=Haze bağlantı yöneticisi kullanan hesaplar için özel hesap yapılandırma kullanıcı arayüzü
Comment[uk]=Інтерфейс користувача для нетипового налаштовування облікового запису за допомогою керування з’єднаннями Haze.
Comment[wa]=Eterface uzeu po-z apontyî a vosse môde les contes tot s' siervant do manaedjeu d' raloyaedje Haze.
Comment[x-test]=xxCustom account configuration user interface for accounts using the Haze connection manager.xx
Comment[zh_CN]=通过 Haze 连接管理器自定义账户的配置界面
Comment[zh_TW]=對使用 Haze 連線管理員的帳號自訂帳號設定使用者介面。
Icon=blockdevice
Name=Haze Account Configuration User Interface
Name[bs]=Korisnički interfejs za konfiguraciju korisničkih naloga Haze
Name[ca]=Interfície d'usuari de configuració de compte de Haze
Name[ca@valencia]=Interfície d'usuari de configuració de compte de Haze
Name[cs]=Uživatelské rozhraní nastavení účtu Haze
Name[da]=Brugerflade til Haze kontokonfiguration
Name[de]=Benutzeroberfläche zur Einrichtung von Haze-Zugängen
Name[el]=Περιβάλλον διαμόρφωσης λογαριασμού χρήστη με Haze
Name[en_GB]=Haze Account Configuration User Interface
Name[es]=Interfaz de configuración de cuentas Haze
Name[et]=Haze'i konto seadistamise kasutajaliides
Name[fi]=Haze-tilinmäärityksen käyttöliittymä
Name[fr]=Interface utilisateur pour la configuration de comptes « Haze ».
Name[gl]=Interface de usuario para a configuración de contas de Haze
Name[hu]=Haze azonosítóbeállító felület
Name[ia]=Interfacie de usator de configuration de conto de Haze
Name[it]=Interfaccia utente di configurazione account Haze
Name[kk]=Haze тіркелгі пайдаланушы интерфейсін баптау
Name[km]=ចំណុច​ប្រទាក់​អ្នក​ប្រើ​ការ​កំណត់​រចនាសម្ព័ន្ធ​គណនី Haze
Name[ko]=Haze 계정 설정 사용자 인터페이스
Name[lt]=Haze paskyros konfigūravimo naudotojo sąsają
Name[nb]=Brukerflate for å sette opp Haze-konto
Name[nds]=Haze-Kontoinstellenböversiet
Name[nl]=Gebruikersinterface voor Haze accountconfiguratie
Name[pl]=Interfejs użytkownika konfiguracji konta Haze
Name[pt]=Interface de Configuração de Contas do Haze
Name[pt_BR]=Interface de configuração de contas do Haze
Name[ro]=Interfață de configurare a conturilor Haze
Name[ru]=Интерфейс для настройки учётной записи Haze
Name[sk]=Používateľské rozhranie konfigurácie účtu Haze
Name[sl]=Uporabniški vmesnik za nastavitev računov Haze
Name[sr]=Корисничко сучеље за подешавање налога под Хејзом
Name[sr@ijekavian]=Корисничко сучеље за подешавање налога под Хејзом
Name[sr@ijekavianlatin]=Korisničko sučelje za podešavanje naloga pod Hazeom
Name[sr@latin]=Korisničko sučelje za podešavanje naloga pod Hazeom
Name[sv]=Användargränssnitt för inställning av Haze-konton
Name[tr]=Haze Hesap Yapılandırma Kullanıcı Arayüzü
Name[uk]=Інтерфейс користувача для налаштовування Haze
Name[wa]=Eterface uzeu d' apontiaedje des contes Haze
Name[x-test]=xxHaze Account Configuration User Interfacexx
Name[zh_CN]=Haze 账户用户配置界面
Name[zh_TW]=Haze 帳號設定使用者介面
Type=Service
ServiceTypes=KTpAccountsKCM/AccountUiPlugin

X-KDE-Library=ktpaccountskcm_plugin_haze
X-KDE-PluginInfo-Author=Dominik Schmidt
X-KDE-PluginInfo-Email=kde@dominik-schmidt.de
X-KDE-PluginInfo-Name=haze
X-KDE-PluginInfo-Version=@KTP_ACCOUNTS_KCM_VERSION@
X-KDE-PluginInfo-Website=http://techbase.kde.org/Projects/Telepathy
X-KDE-PluginInfo-License=GPL
X-KDE-PluginInfo-EnabledByDefault=true

==> ktp-accounts-kcm_0.9.0.orig.tar.bz2: ktp-accounts-kcm-0.9.0/plugins/haze/ktpaccountskcm_plugin_haze.desktop.cmake <==
[Desktop Entry]
Encoding=UTF-8
Comment=Custom account configuration user interface for accounts using the Haze connection manager.
Comment[bs]=Korisnički interfejs za konfiguraciju korisničkih naloga koristeći Haze menadžer konekcja.
Comment[ca]=Interfície d'usuari de configuració de compte personalitzat per comptes que utilitzen el gestor de connexions Haze.
Comment[ca@valencia]=Interfície d'usuari de configuració de compte personalitzat per comptes que utilitzen el gestor de connexions Haze.
Comment[cs]=Vlastní uživatelské rozhraní nastavení účtů pro účty používající správce spojení Haze.
Comment[da]=Brugerflade til brugertilpasset kontokonfiguration til konti der bruger forbindelseshåndteringen Haze.
Comment[de]=Eigene Benutzeroberfläche zum Einrichten von Zugängen, die die Haze-Verbindungsverwaltung verwenden.
Comment[el]=Περιβάλλον προσαρμοσμένης διαμόρφωσης λογαριασμού χρήστη για λογαριασμούς που χρησιμοποιούν το διαχειριστή συνδέσεων Haze.
Comment[en_GB]=Custom account configuration user interface for accounts using the Haze connection manager.
Comment[es]=Interfaz de configuración de cuentas personalizadas para las cuentas que usen el gestor de conexiones Haze.
Comment[et]=Haze'i ühendusehaldurit kasutavate kontode kohandatud konto seadistamise kasutajaliides
Comment[fi]=Haze-yhteyshallintaa käyttävien tilien mukautettu hallintakäyttöliittymä.
Comment[fr]=Interface utilisateur personnalisée pour la configuration de comptes en utilisant le gestionnaire de connexions « Haze ».
Comment[gl]=Interface de usuario de configuración personalizada da conta para contas que empreguen o xestor de conexións Haze.
Comment[hu]=Egyedi beállítófelület a Haze kapcsolatkezelőt használó azonosítókhoz.
Comment[ia]=Interfacie de usator pro configuration de conto personalisate pro contos usante le gerente de connexion Haze.
Comment[it]=Interfaccia utente personalizzata di configurazione account per account che usano il gestore di connessioni Haze.
Comment[kk]=Haze байланыс менеджерін қолданатын тіркелгі пайдаланушы интерфейс параметрлерін ыңғайлау.
Comment[km]=ចំណុច​ប្រទាក់​អ្នក​ប្រើ​ការ​កំណត់​រចនាសម្ព័ន្ធ​គណនី​ផ្ទាល់​ខ្លួន​សម្រាប់​គណនី​ដែល​បាន​ប្រើ​កម្មវិធី​គ្រប់គ្រង​ការ​តភ្ជាប់​ Haze ។
Comment[ko]=Haze 연결 관리자를 사용하는 계정 설정 사용자 인터페이스입니다.
Comment[lt]=Savito paskyros konfigūravimo naudotojo sąsaja paskyroms naudojant Haze ryšio tvarkyklę.
Comment[nb]=Brukerflate for å sette opp egendefinerte kontoer ved bruk av Haze tilkoblingsbehandler.
Comment[nds]=Topasst Kontoinstellen-Böversiet för Kontos, de den Verbinnenpleger „Haze“ bruukt
Comment[nl]=Gebruikersinterface voor aangepaste accountconfiguratie voor accounts die de Haze verbindingenbeheerder gebruiken.
Comment[pl]=Dostosowana nakładka graficzna do ustawiania kont dla kont wykorzystujących usługę połączeń Haze.
Comment[pt]=Interface de utilizador de configuração de contas personalizadas com o gestor de ligações Haze.
Comment[pt_BR]=Interface de configuração de contas personalizadas usando o gerenciador de conexões Haze.
Comment[ro]=Interfață personalizată de configurare a conturilor folosind gestionarul de conexiuni Haze.
Comment[ru]=Пользовательский интерфейс для настройки учётной записи с помощью менеджера соединений Haze.
Comment[sk]=Vlastné používateľské rozhranie konfigurácie účtu pre účty používajúce správcu pripojení Haze.
Comment[sl]=Uporabniški vmesnik za prilagoditev računov, ki uporabljajo upravljalnik povezav Haze.
Comment[sr]=Корисничко сучеље за подешавање посебних налога под менаџером везе Хејз.
Comment[sr@ijekavian]=Корисничко сучеље за подешавање посебних налога под менаџером везе Хејз.
Comment[sr@ijekavianlatin]=Korisničko sučelje za podešavanje posebnih naloga pod menadžerom veze Haze.
Comment[sr@latin]=Korisničko sučelje za podešavanje posebnih naloga pod menadžerom veze Haze.
Comment[sv]=Användargränssnitt för anpassad kontoinställning av konton som använder anslutningshanteraren Haze.
Comment[tr]=Haze bağlantı yöneticisi kullanan hesaplar için özel hesap yapılandırma kullanıcı arayüzü
Comment[uk]=Інтерфейс користувача для нетипового налаштовування облікового запису за допомогою керування з’єднаннями Haze.
Comment[wa]=Eterface uzeu po-z apontyî a vosse môde les contes tot s' siervant do manaedjeu d' raloyaedje Haze.
Comment[x-test]=xxCustom account configuration user interface for accounts using the Haze connection manager.xx
Comment[zh_CN]=通过 Haze 连接管理器自定义账户的配置界面
Comment[zh_TW]=對使用 Haze 連線管理員的帳號自訂帳號設定使用者介面。
Icon=blockdevice
Name=Haze Account Configuration User Interface
Name[bs]=Korisnički interfejs za konfiguraciju korisničkih naloga Haze
Name[ca]=Interfície d'usuari de configuració de compte de Haze
Name[ca@valencia]=Interfície d'usuari de configuració de compte de Haze
Name[cs]=Uživatelské rozhraní nastavení účtu Haze
Name[da]=Brugerflade til Haze kontokonfiguration
Name[de]=Benutzeroberfläche zur Einrichtung von Haze-Zugängen
Name[el]=Περιβάλλον διαμόρφωσης λογαριασμού χρήστη με Haze
Name[en_GB]=Haze Account Configuration User Interface
Name[es]=Interfaz de configuración de cuentas Haze
Name[et]=Haze'i konto seadistamise kasutajaliides
Name[fi]=Haze-tilinmäärityksen käyttöliittymä
Name[fr]=Interface utilisateur pour la configuration de comptes « Haze ».
Name[gl]=Interface de usuario para a configuración de contas de Haze
Name[hu]=Haze azonosítóbeállító felület
Name[ia]=Interfacie de usator de configuration de conto de Haze
Name[it]=Interfaccia utente di configurazione account Haze
Name[kk]=Haze тіркелгі пайдаланушы интерфейсін баптау
Name[km]=ចំណុច​ប្រទាក់​អ្នក​ប្រើ​ការ​កំណត់​រចនាសម្ព័ន្ធ​គណនី Haze
Name[ko]=Haze 계정 설정 사용자 인터페이스
Name[lt]=Haze paskyros konfigūravimo naudotojo sąsają
Name[nb]=Brukerflate for å sette opp Haze-konto
Name[nds]=Haze-Kontoinstellenböversiet
Name[nl]=Gebruikersinterface voor Haze accountconfiguratie
Name[pl]=Nakładka graficzna do ustawiania konta Haze
Name[pt]=Interface de Configuração de Contas do Haze
Name[pt_BR]=Interface de configuração de contas do Haze
Name[ro]=Interfață de configurare a conturilor Haze
Name[ru]=Интерфейс для настройки учётной записи Haze
Name[sk]=Používateľské rozhranie konfigurácie účtu Haze
Name[sl]=Uporabniški vmesnik za nastavitev računov Haze
Name[sr]=Корисничко сучеље за подешавање налога под Хејзом
Name[sr@ijekavian]=Корисничко сучеље за подешавање налога под Хејзом
Name[sr@ijekavianlatin]=Korisničko sučelje za podešavanje naloga pod Hazeom
Name[sr@latin]=Korisničko sučelje za podešavanje naloga pod Hazeom
Name[sv]=Användargränssnitt för inställning av Haze-konton
Name[tr]=Haze Hesap Yapılandırma Kullanıcı Arayüzü
Name[uk]=Інтерфейс користувача для налаштовування Haze
Name[wa]=Eterface uzeu d' apontiaedje des contes Haze
Name[x-test]=xxHaze Account Configuration User Interfacexx
Name[zh_CN]=Haze 账户用户配置界面
Name[zh_TW]=Haze 帳號設定使用者介面
Type=Service
ServiceTypes=KTpAccountsKCM/AccountUiPlugin

X-KDE-Library=ktpaccountskcm_plugin_haze
X-KDE-PluginInfo-Author=Dominik Schmidt
X-KDE-PluginInfo-Email=kde@dominik-schmidt.de
X-KDE-PluginInfo-Name=haze
X-KDE-PluginInfo-Version=@KTP_ACCOUNTS_KCM_VERSION@
X-KDE-PluginInfo-Website=http://techbase.kde.org/Projects/Telepathy
X-KDE-PluginInfo-License=GPL
X-KDE-PluginInfo-EnabledByDefault=true
